@@ -181,7 +181,7 @@ function formulaires_editer_auteur_verifier_dist(
 		$erreurs['nom'] = _T('info_nom_pas_conforme');
 	}
 
-	if ($email = _request('email')) {
+	if ($email = trim(_request('email'))) {
 		include_spip('inc/filtres');
 		include_spip('inc/autoriser');
 		// un redacteur qui modifie son email n'a pas le droit de le vider si il y en avait un
@@ -210,14 +210,13 @@ function formulaires_editer_auteur_verifier_dist(
 			} else {
 				#Un auteur existe deja avec cette adresse ? et n'est pas le user courant.
 				if (
-					(sql_countsel(
+					sql_countsel(
 						'spip_auteurs',
-						'email=' . sql_quote($email)
-					) > 0) and ($id_auteur != ($id_auteur_ancien = sql_getfetsel(
-						'id_auteur',
-						'spip_auteurs',
-						'email=' . sql_quote($email)
-					)))
+						[
+							'email = ' . sql_quote($email),
+							'id_auteur <> '.intval($id_auteur)
+						]
+					) > 0
 				) {
 					$erreurs['email'] = _T('erreur_email_deja_existant');
 				}
@@ -487,7 +486,9 @@ function auteur_regenerer_identifiants($id_auteur, $notifier = true, $contexte =
 		$set['pass'] = creer_pass_aleatoire(max(_PASS_LONGUEUR_MINI, 16));
 
 		include_spip('action/editer_auteur');
-		auteur_modifier($id_auteur, $set);
+		if (auteur_modifier($id_auteur, $set) !== '') {
+			return '';
+		}
 
 		$row = sql_fetsel('*', 'spip_auteurs', 'id_auteur=' . intval($id_auteur));
 		include_spip('inc/filtres');
