@@ -123,7 +123,7 @@ function auth_echec($raison) {
 			_T('avis_erreur_connexion'),
 			_T('avis_erreur_visiteur')
 				// Lien vers le site public
-				. '<br /><a href="' . attribut_url(url_de_base()) . '">' . _T('login_retour_public') . '</a>'
+				. '<br><a href="' . attribut_url(url_de_base()) . '">' . _T('login_retour_public') . '</a>'
 				// Si la personne est connectée, lien de déconnexion ramenant vers la page de login
 				. ($est_connecte ? ' | <a href="' . generer_url_public('', 'action=logout&amp;logout=prive') . '">' . _T('icone_deconnecter') . '</a>' : '')
 		);
@@ -132,7 +132,7 @@ function auth_echec($raison) {
 		$h = $raison['site'];
 		$raison = minipres(
 			_T('avis_erreur_connexion'),
-			'<br /><br /><p>'
+			'<br><br><p>'
 			. _T('texte_inc_auth_1', ['auth_login' => $raison['login']])
 			. " <a href='" . attribut_url($h) . "'>"
 			. _T('texte_inc_auth_2')
@@ -276,8 +276,6 @@ function auth_init_droits($row) {
 	// si prefs pas definies, les definir par defaut
 	if (!isset($GLOBALS['visiteur_session']['prefs']['couleur'])) {
 		$GLOBALS['visiteur_session']['prefs']['couleur'] = 2;
-		$GLOBALS['visiteur_session']['prefs']['display'] = 2;
-		$GLOBALS['visiteur_session']['prefs']['display_navigation'] = 'navigation_avec_icones';
 	}
 
 	$GLOBALS['visiteur_session'] = pipeline(
