@@ -277,7 +277,7 @@ function statut_effacer_images_temporaires($stat) {
  * @uses reconstruire_image_intermediaire()
  *
  * @param string $img
- *     Chemin de l'image ou balise html `<img src=... />`.
+ *     Chemin de l'image ou balise html `<img src=...>`.
  * @param string $effet
  *     Les nom et paramètres de l'effet à apporter sur l'image
  *     (par exemple : reduire-300-200).
@@ -319,10 +319,10 @@ function _image_valeurs_trans($img, $effet, $forcer_format = false, $fonction_cr
 	if (strlen($source) < 1) {
 		if (strpos($img, '<img ') !== 0) {
 			$source = $img;
-			$img = "<img src='$source' />";
+			$img = "<img src='$source'>";
 		}
 		else {
-			// pas d'attribut src sur cette balise <img../>
+			// pas d'attribut src sur cette balise <img..>
 			return false;
 		}
 	} elseif (
@@ -1274,9 +1274,6 @@ function _image_tag_changer_taille($tag, $width, $height, $style = false) {
 function _image_ecrire_tag($valeurs, $surcharge = []) {
 	$valeurs = pipeline('image_ecrire_tag_preparer', $valeurs);
 
-	// fermer les tags img pas bien fermes;
-	$tag = str_replace('>', '/>', str_replace('/>', '>', $valeurs['tag']));
-
 	// le style
 	$style = $valeurs['style'];
 	if (isset($surcharge['style'])) {
@@ -1296,6 +1293,9 @@ function _image_ecrire_tag($valeurs, $surcharge = []) {
 		unset($surcharge['height']);
 	}
 
+	// fermer les tags img pas bien fermes;
+	$tag = str_replace('/>', '>', (string) $valeurs['tag']);
+
 	$tag = _image_tag_changer_taille($tag, $width, $height, $style);
 	// traiter specifiquement le src qui peut etre repris dans un onmouseout
 	// on remplace toute les ref a src dans le tag
