@@ -181,7 +181,7 @@ function lire_fichier($fichier, &$contenu, $options = []) {
 
 		#spip_log("$fread $fichier ".spip_timer('lire_fichier'));
 		if (!$ok) {
-			spip_log("echec lecture $fichier");
+			spip_log("echec lecture $fichier", 'flock.' . _LOG_ERREUR);
 		}
 
 		return $ok;
@@ -225,59 +225,59 @@ function ecrire_fichier($fichier, $contenu, $ignorer_echec = false, $truncate =
 		if (substr($fichier, -3) == '.gz') {
 			$contenu = gzencode($contenu);
 		}
+		$longueur_a_ecrire = strlen($contenu);
+
 		// si c'est une ecriture avec troncation , on fait plutot une ecriture complete a cote suivie unlink+rename
 		// pour etre sur d'avoir une operation atomique
 		// y compris en NFS : http://www.ietf.org/rfc/rfc1094.txt
-		// sauf sous wintruc ou ca ne marche pas
 		$ok = false;
-		if ($truncate and _OS_SERVEUR != 'windows') {
+		if ($truncate) {
 			if (!function_exists('creer_uniqid')) {
 				include_spip('inc/acces');
 			}
 			$id = creer_uniqid();
-			// on ouvre un pointeur sur un fichier temporaire en ecriture +raz
-			if ($fp2 = spip_fopen_lock("$fichier.$id", 'w', LOCK_EX)) {
-				$s = @fputs($fp2, $contenu, $a = strlen($contenu));
-				$ok = ($s == $a);
-				spip_fclose_unlock($fp2);
+			// on ecrit dans un fichier temporaire avec lock
+			$l = file_put_contents("$fichier.$id", $contenu, LOCK_EX);
+			if ($l === $longueur_a_ecrire) {
 				spip_fclose_unlock($fp);
 				$fp = null;
-				// unlink direct et pas spip_unlink car on avait deja le verrou
-				// a priori pas besoin car rename ecrase la cible
-				// @unlink($fichier);
-				// le rename aussitot, atomique quand on est pas sous windows
-				// au pire on arrive en second en cas de concourance, et le rename echoue
+				// on rename vers la cible, ce qui est atomique quand on est pas sous windows
+				// au pire on arrive en second en cas de concurence, et le rename echoue
 				// --> on a la version de l'autre process qui doit etre identique
-				@rename("$fichier.$id", $fichier);
-				// precaution en cas d'echec du rename
-				if (!_TEST_FILE_EXISTS or @file_exists("$fichier.$id")) {
-					@unlink("$fichier.$id");
-				}
-				if ($ok) {
+				// sur certains fs lent, il semble que le rename echoue parce que notre propre lock est pas libéré assez vite...
+				// ce cas sera traité par le fallback avec eventuellement une tempo si besoin
+				if (@rename("$fichier.$id", $fichier)) {
 					$ok = file_exists($fichier);
 				}
-			} else // echec mais penser a fermer ..
-			{
-				spip_fclose_unlock($fp);
-				$fp = null;
+			}
+			// precaution en cas d'echec du rename
+			if (!_TEST_FILE_EXISTS || @file_exists("$fichier.$id")) {
+				@unlink("$fichier.$id");
 			}
 		}
-		// sinon ou si methode precedente a echoueee
-		// on se rabat sur la methode ancienne
-		if (!$ok and !is_null($fp)) {
-			// ici on est en ajout ou sous windows, cas desespere
-			if ($truncate) {
-				@ftruncate($fp, 0);
-			}
-			$s = @fputs($fp, $contenu, $a = strlen($contenu));
-
-			$ok = ($s == $a);
+		if (!is_null($fp)) {
 			spip_fclose_unlock($fp);
 		}
-		// on tente une dernière fois file_put_contents
+
+		// sinon ou si methode precedente a echoueee
+		// on se rabat sur file_put_contents direct sur le fichier
 		if (!$ok) {
+			clearstatcache();
 			$l = file_put_contents($fichier, $contenu, $truncate ? LOCK_EX : LOCK_EX | FILE_APPEND);
-			$ok = ($l === strlen($contenu));
+			$ok = ($l === $longueur_a_ecrire);
+			if ($truncate) {
+				spip_log('ecrire_fichier: operation atomique via rename() impossible, fallback non atomique via file_put_contents' . ($ok ? 'OK' : 'Fail'), 'flock.' . _LOG_INFO_IMPORTANTE);
+			}
+			if (!$ok) {
+				// derniere tentative : on sait que file_put_contents marche dans le dossier considere
+				// c'est peut etre un probleme de tempo avant que le lock qu'on a nous meme posé soit libéré (fs lent)
+				usleep(250000);
+				$l = file_put_contents($fichier, $contenu, $truncate ? LOCK_EX : LOCK_EX | FILE_APPEND);
+				$ok = ($l === $longueur_a_ecrire);
+				if ($truncate) {
+					spip_log('ecrire_fichier: operation atomique via rename() impossible, fallback non atomique via tempo + file_put_contents : ' . ($ok ? 'OK' : 'Fail'), 'flock.' . _LOG_INFO_IMPORTANTE);
+				}
+			}
 		}
 
 		// liberer le verrou et fermer le fichier
@@ -298,7 +298,7 @@ function ecrire_fichier($fichier, $contenu, $ignorer_echec = false, $truncate =
 		}
 		spip_unlink($fichier);
 	}
-	spip_log("Ecriture fichier $fichier impossible", _LOG_INFO_IMPORTANTE);
+	spip_log("Ecriture fichier $fichier impossible", 'flock.' . _LOG_INFO_IMPORTANTE);
 
 	return false;
 }
@@ -320,8 +320,8 @@ function ecrire_fichier($fichier, $contenu, $ignorer_echec = false, $truncate =
  *     Écriture avec troncation ?
  */
 function ecrire_fichier_securise($fichier, $contenu, $ecrire_quand_meme = false, $truncate = true) {
-	if (substr($fichier, -4) !== '.php') {
-		spip_log('Erreur de programmation: ' . $fichier . ' doit finir par .php');
+	if (!str_ends_with($fichier, '.php')) {
+		spip_log('Erreur de programmation: ' . $fichier . ' doit finir par .php', 'flock.' . _LOG_ERREUR);
 	}
 	$contenu = '<' . "?php die ('Acces interdit'); ?" . ">\n" . $contenu;
 
@@ -333,10 +333,13 @@ function ecrire_fichier_securise($fichier, $contenu, $ecrire_quand_meme = false,
  * @param string $fichier
  * @param string $contenu
  * @param bool $force
- * @return bool
+ * @return ?bool
+ *   false en cas d'erreur
+ *   true en cas d'ecriture suite à modification
+ *   null si fichier inchangé car pas de modif
  */
-function ecrire_fichier_calcule_si_modifie($fichier, $contenu, $force = false, $use_copy = false) {
-	$fichier_tmp = $fichier . '.last';
+function ecrire_fichier_calcule_si_modifie($fichier, $contenu, $force = false) {
+	$fichier_tmp = $fichier . '.tmp.' . uniqid();
 	if (!ecrire_fichier($fichier_tmp, $contenu, true)) {
 		return false;
 	}
@@ -345,16 +348,13 @@ function ecrire_fichier_calcule_si_modifie($fichier, $contenu, $force = false, $
 		or !file_exists($fichier)
 		or md5_file($fichier) != md5_file($fichier_tmp)
 	) {
-		if ($use_copy) {
-			@copy($fichier_tmp, $fichier);
-		}
-		else {
-			@rename($fichier_tmp, $fichier);
-		}
+		@rename($fichier_tmp, $fichier);
 		// eviter que PHP ne reserve le vieux timestamp
 		clearstatcache(true, $fichier);
+		return true;
 	}
-	return true;
+	@unlink($fichier_tmp);
+	return null;
 }
 
 
@@ -549,7 +549,7 @@ function spip_attend_invalidation_opcode_cache($timestamp = null) {
 				$wait = 0;
 			}
 		}
-		spip_log('Probleme de configuration opcache.revalidate_freq ' . $duree . 's : on attend ' . $wait . 's', _LOG_INFO_IMPORTANTE);
+		spip_log('Probleme de configuration opcache.revalidate_freq ' . $duree . 's : on attend ' . $wait . 's', 'flock.' . _LOG_INFO_IMPORTANTE);
 		if ($wait) {
 			sleep($duree + 1);
 		}
@@ -649,14 +649,14 @@ function sous_repertoire($base, $subdir = '', $nobase = false, $tantpis = false)
 
 	if (is_dir($path) && is_writable($path)) {
 		@touch("$path/.ok");
-		spip_log("creation $base$subdir/");
+		spip_log("creation $base$subdir/", 'flock.' . _LOG_ERREUR);
 
 		return $baseaff . ($dirs[$base . $subdir] = "$subdir/");
 	}
 
 	// en cas d'echec c'est peut etre tout simplement que le disque est plein :
 	// l'inode du fichier dir_test existe, mais impossible d'y mettre du contenu
-	spip_log("echec creation $base{$subdir}");
+	spip_log("echec creation $base{$subdir}", 'flock.' . _LOG_ERREUR);
 	if ($tantpis) {
 		return '';
 	}
