@@ -420,6 +420,16 @@
 
 				cfg = $.extend({template: litySpip.template(cfg, type, groupName, groupPosition, groupLength)}, cfg);
 				//console.log("Call lity "+cfg.handler+' '+target);
+
+				// est-ce qu'on veut rester sur le meme niveau de popin (pas d'empilage) ?
+				//console.log("samePopin", cfg.samePopin, lity.current());
+				if (cfg.samePopin) {
+					var l = lity.current();
+					if (l) {
+						l.close();
+					}
+				}
+
 				lity(target, cfg, opener);
 			}
 
