@@ -131,7 +131,7 @@ function balise_DESCRIPTIF_SITE_SPIP_dist($p) {
  * @link https://www.spip.net/4331
  * @example
  *     ```
- *     <meta http-equiv="Content-Type" content="text/html; charset=#CHARSET" />
+ *     <meta charset="#CHARSET">
  *     ```
  *
  * @param Champ $p
@@ -391,7 +391,7 @@ function balise_SQUELETTE_dist($p) {
  * @see spip_version()
  * @example
  *     ```
- *     [<meta name="generator" content="SPIP (#SPIP_VERSION|header_silencieux)" />]
+ *     [<meta name="generator" content="SPIP (#SPIP_VERSION|header_silencieux)">]
  *     ```
  *
  * @param Champ $p
@@ -1272,8 +1272,8 @@ function balise_SELF_dist($p) {
  * @see find_in_path() Recherche de chemin
  * @example
  *     ```
- *     [<script type="text/javascript" src="(#CHEMIN{javascript/jquery.flot.js})"></script>]
- *     [<link rel="stylesheet" href="(#CHEMIN{css/perso.css}|direction_css)" type="text/css" />]
+ *     [<script src="(#CHEMIN{javascript/jquery.flot.js})"></script>]
+ *     [<link rel="stylesheet" href="(#CHEMIN{css/perso.css}|direction_css)" type="text/css">]
  *     ```
  *
  * @param Champ $p
@@ -2524,11 +2524,11 @@ function balise_ACTION_FORMULAIRE($p) {
 	$p->code = "	'<span class=\"form-hidden\">' .
 	form_hidden($_url) .
 	'<input name=\'formulaire_action\' type=\'hidden\'
-		value=\'' . $_form . '\' />' .
+		value=\'' . $_form . '\'>' .
 	'<input name=\'formulaire_action_args\' type=\'hidden\'
-		value=\'' . (\$Pile[0]['formulaire_args'] ?? '') . '\' />' .
+		value=\'' . (\$Pile[0]['formulaire_args'] ?? '') . '\'>' .
 	'<input name=\'formulaire_action_sign\' type=\'hidden\'
-		value=\'' . (\$Pile[0]['formulaire_sign'] ?? '') . '\' />' .
+		value=\'' . (\$Pile[0]['formulaire_sign'] ?? '') . '\'>' .
 	(\$Pile[0]['_hidden'] ?? '') .
 	'</span>'";
 
@@ -2630,7 +2630,7 @@ function balise_SLOGAN_SITE_SPIP_dist($p) {
  * @example
  *     ```
  *     [(#HTML5) required="required"]
- *     <input[ (#HTML5|?{type="email",type="text"})] ... />
+ *     <input[ (#HTML5|?{type="email",type="text"})] ...>
  *     ```
  *
  * @param Champ $p
@@ -2813,7 +2813,7 @@ function balise_PUBLIE_dist($p) {
  * @link https://www.spip.net/5505
  * @example
  *     ```
- *     <link rel="stylesheet" type="text/css" href="#PRODUIRE{fond=css/macss.css,couleur=ffffff}" />
+ *     <link rel="stylesheet" type="text/css" href="#PRODUIRE{fond=css/macss.css,couleur=ffffff}">
  *     ```
  *
  * @param Champ $p
