@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -166,9 +165,10 @@ function analyser_backend($rss, $url_syndic = '') {
 				',<guid.*>[[:space:]]*(https?:[^<]*)</guid>,Uims',
 				$item,
 				$regs
-			) and preg_match(
+			)
+			and preg_match(
 				',^(true|1)?$,i',
-				extraire_attribut($regs[0], 'ispermalink')
+				extraire_attribut($regs[0], 'ispermalink') ?? ''
 			)
 		) {
 			$data['url'] = $regs[1];
@@ -385,9 +385,14 @@ function analyser_backend($rss, $url_syndic = '') {
 			);
 		}
 
-		// GitHub : Identification du commit
-		if (preg_match(',<id>[^/]+/(\w+)</id>,Uims', $item, $regs)) {
-			$data['id_commit'] = $regs[1];
+		// Récupération de l'id quelqu'il soit
+		if (preg_match(',<id>(.+)</id>,Uims', $item, $regs)) {
+			$data['id'] = $regs[1];
+
+			// GitHub et Gitlab : Identification du commit ou du ticket
+			if (preg_match(',(?:commit|issues)/(\w+)$,Uims', $data['id'], $regs)) {
+				$data['id_commit'] = $regs[1];
+			}
 		}
 
 		// tags
