@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'archiver' => 'Archive',
@@ -15,8 +11,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'archiver_concatener_ignorer' => 'The visits of at least @nb@ years are not affected.',
 	'archiver_concatener_par_an' => 'Additional visits of @nb@ years will be combined, for every article, on the first day of every year.',
 	'archiver_concatener_par_mois' => 'Additional visits of @nb@ years will be combined, for every article, on the first day of every month.',
-	'archiver_conseil_sauvegarde' => 'It is advisable to backup the database first.',
-	'archiver_description' => 'This page provides tools to clean or archive the statistics of the site.',
 	'archiver_et_nettoyer' => 'Archive and clean',
 	'archiver_nettoyer' => 'Clean',
 	'archiver_nettoyer_explications' => 'Removes lines of "referrers" or "visits" to which items do not exist (anymore) in the database.',
@@ -24,7 +18,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'archiver_nettoyer_visites_articles' => 'Clean visites_articles',
 	'archiver_nombre_lignes' => 'Number of lines',
 	'archiver_operation_longue' => 'This operation could take a lot of time especially on the first execution.',
-	'archiver_operations_irreversibles' => 'These operations can’t be undone!',
 
 	// B
 	'bouton_effacer_referers' => 'Delete only incoming links',
@@ -77,7 +70,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'onglet_repartition_lang' => 'Distribution by language',
 
 	// R
-	'resume' => 'Resume',
+	'resume' => 'Summary',
 
 	// T
 	'texte_admin_effacer_stats' => 'This command deletes all statistics on visits to the site, including article popularity.',
@@ -94,5 +87,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'visites_annuelles' => 'Number of visits per year',
 	'visites_hebdomadaires' => 'Number of visits per week',
 	'visites_journalieres' => 'Number of visits per day',
-	'visites_mensuelles' => 'Number of visits per month'
-);
+	'visites_mensuelles' => 'Number of visits per month',
+];
