@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=fr_tu
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'archiver' => 'Archiver',
@@ -15,8 +11,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'archiver_concatener_ignorer' => 'Les visites de moins de @nb@ ans ne sont pas touchées.',
 	'archiver_concatener_par_an' => 'Les visites de plus de @nb@ ans seront concaténées, pour chaque article, dans le premier jour de chaque année.',
 	'archiver_concatener_par_mois' => 'Les visites de plus de @nb@ ans seront concaténées, pour chaque article, dans le premier jour de chaque mois.',
-	'archiver_conseil_sauvegarde' => 'Il est conseillé de faire une sauvegarde préalable de la base de données.',
-	'archiver_description' => 'Cette page fournit des outils pour nettoyer ou archiver les statistiques du site.',
 	'archiver_et_nettoyer' => 'Archiver et nettoyer',
 	'archiver_nettoyer' => 'Nettoyer',
 	'archiver_nettoyer_explications' => 'Enlève les lignes de "réferers" ou de "visites" dont les articles n’existent pas (ou plus) dans la base de données.',
@@ -24,7 +18,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'archiver_nettoyer_visites_articles' => 'Nettoyer visites_articles',
 	'archiver_nombre_lignes' => 'Nombre de lignes',
 	'archiver_operation_longue' => 'Cette opération peut être très longue, surtout lors de la première exécution.',
-	'archiver_operations_irreversibles' => 'Ces opérations sont irréversibles !',
 
 	// B
 	'bouton_effacer_referers' => 'Effacer seulement les liens entrants',
@@ -94,5 +87,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'visites_annuelles' => 'Nombre de visites par an',
 	'visites_hebdomadaires' => 'Nombre de visites par semaine',
 	'visites_journalieres' => 'Nombre de visites par jour',
-	'visites_mensuelles' => 'Nombre de visites par mois'
-);
+	'visites_mensuelles' => 'Nombre de visites par mois',
+];
