@@ -179,14 +179,6 @@ function interdire_scripts($arg, $mode_filtre = null) {
 		$t = textebrut($arg);
 	}
 
-	// Reinserer les echappements des modeles
-	if (defined('_PROTEGE_JS_MODELES')) {
-		$t = echappe_retour($t, 'javascript' . _PROTEGE_JS_MODELES);
-	}
-	if (defined('_PROTEGE_PHP_MODELES')) {
-		$t = echappe_retour($t, 'php' . _PROTEGE_PHP_MODELES);
-	}
-
 	return $dejavu[$mode_filtre][$arg] = $t;
 }
 
@@ -257,7 +249,7 @@ function typo($letexte, $echapper = true, $connect = null, $env = []) {
 		  'connect' => $connect,
 		  'env' => $env,
 		];
-		$letexte = echappe_html($letexte, $echapper, false, '', '', $callback_options);
+		$letexte = echappe_html($letexte, $echapper, false, null, '', $callback_options);
 	}
 
 	//
@@ -892,7 +884,7 @@ function propre($t, $connect = null, $env = []) {
 		  'connect' => $connect,
 		  'env' => $env,
 		];
-		$t_echappe = echappe_html($t, '', false, '', '', $callback_options);
+		$t_echappe = echappe_html($t, '', false, null, '', $callback_options);
 
 		// avant echapper_html_suspect il faut protéger les raccourcis SPIP pas encore traités qui ressemblent à des balises html
 		$t_echappe = echappe_html($t_echappe, 'raccourcis', true, "@</?(quote|poesie|poetry)([^>]*?)(/?)>@isS");
@@ -903,7 +895,7 @@ function propre($t, $connect = null, $env = []) {
 		$t = echappe_retour($t, 'raccourcis');
 	}
 	else {
-		$t = echappe_html($t, '', false, '', '', ['connect' => $connect, 'env' => $env]);
+		$t = echappe_html($t, '', false, null, '', ['connect' => $connect, 'env' => $env]);
 	}
 
 	$t = expanser_liens($t, $connect ?? '', $env);
